CLFButtonFramework class

A button framework including the callback, text and icon.

Used to bypass holding StatefulWidgets in a list.

Constructors

CLFButtonFramework({VoidCallback? callback, IconData? icon, String? text})
const

Properties

callback VoidCallback?
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited