Components for CLIMS mobile application
Features
It has a stepper and a button component for now
Usage
Add the package to project dependencies to use it. In order to use debugging and hot reload functionalities, place the projects as following:
MyFolder/ ├── climsmobile/ │ └── camloginapp/ │ └── dev.code-workspace ├── vrsmobiledesign/ │ └── pubspec.yaml
After having this setup, use VS Code's "File -> Open Workspace from File" menu option to allow for realtime updating and hot reload with local package repository.
When you want to publish a new version, we will use a package that automates bumping version numbers called Cider.
1-Install it using "dart pub global activate cider" command on your terminal.
2-Use it with "dart pub global run cider bump
3-Do not forget to push the changes to gitlab after publishing, they are expected to match at all times.